Stan Math Library: stan/math/rev/scal/fun/is_nan.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_nan.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_IS_NAN_HPP
2 #define STAN_MATH_REV_SCAL_FUN_IS_NAN_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <stan/math/prim/scal/fun/is_nan.hpp>
6 #include <stan/math/prim/scal/fun/constants.hpp>
7
8 namespace stan {
9
10 namespace math {
11
21 inline bool is_nan(const var& v) {
22 return stan::math::is_nan(v.val());
23 }
24
25 }
26 }
27
28 #endif
core.hpp
is_nan.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
constants.hpp
stan::math::var::val
double val() const
Return the value of this variable.
Definition: var.hpp:233
stan::math::is_nan
int is_nan(const fvar< T > &x)
Returns 1 if the input's value is NaN and 0 otherwise.
Definition: is_nan.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.